@@ -50,7 +50,6 @@ from biolib.common import (make_sure_path_exists,
 from biolib.external.prodigal import Prodigal
 from biolib.external.execute import check_dependencies
 
-
 class OptionsParser():
     def __init__(self):
         """Initialization"""
@@ -207,7 +206,7 @@ class OptionsParser():
 
     def taxon_profile(self, options):
         """Call genes command"""
-        
+
         make_sure_path_exists(options.output_dir)
         check_file_exists(options.scaffold_stats_file)
         check_file_exists(options.taxonomy_file)
@@ -281,7 +280,7 @@ class OptionsParser():
         self.logger.info('Outlier information written to: ' + outlier_file)
 
         # create outlier plots
-        if not options.no_plots:
+        if options.create_plots:
             plot_dir = os.path.join(options.output_dir, 'plots')
             make_sure_path_exists(plot_dir)
         
@@ -499,6 +498,7 @@ class OptionsParser():
 
         make_sure_path_exists(os.path.dirname(options.output_genome))
 
+        options.compatible_file = None #*** Removed with Python 3 port       
         if not (options.add or options.remove or options.outlier_file or options.compatible_file):
             self.logger.warning('No modification to bin requested.\n')
             sys.exit()
@@ -549,12 +549,12 @@ class OptionsParser():
         if failed_to_add:
             self.logger.warning('Failed to add the following sequence(s):')
             for seq_id in failed_to_add:
-                print '    %s' % seq_id
+                print('    %s' % seq_id)
 
         if failed_to_remove:
             self.logger.warning('Failed to remove the following sequence(s):')
             for seq_id in failed_to_remove:
-                print '    %s' % seq_id
+                print('    %s' % seq_id)
 
         self.logger.info('Modified genome written to: ' + options.output_genome)
         
@@ -630,7 +630,7 @@ class OptionsParser():
                         self.logger.info('There are %d sequences shared between %s and %s:' % (len(dup_seq_ids), genome_idA, genome_idB))
 
                     for seq_id in dup_seq_ids:
-                        print '    %s' % seq_id
+                        print('    %s' % seq_id)
 
     def bin_compare(self, options):
         """Bin compare command"""
@@ -673,8 +673,6 @@ class OptionsParser():
     def parse_options(self, options):
         """Parse user options and call the correct pipeline(s)"""
 
-        check_dependencies(('diamond', 'ktImportText'))
-
         if(options.subparser_name == 'scaffold_stats'):
             self.scaffold_stats(options)
         elif(options.subparser_name == 'genome_stats'):
